@@ -1,7 +1,5 @@
 from webob import Request
 import datetime
-import json
-
 
 def asbool(obj):
     if isinstance(obj, (str, unicode)):
@@ -15,15 +13,18 @@ def asbool(obj):
                 "String is not true/false: %r" % obj)
     return bool(obj)
 
-
-class DateTimeEncoder(json.JSONEncoder):
-    def default(self, obj):
-        if isinstance(obj, datetime.date):
-            return obj.isoformat()
-        if isinstance(obj, datetime.datetime):
-            return obj.isoformat()
-        return json.JSONEncoder.default(self, obj)
-
+def aslist(obj, sep=None, strip=True):
+    if isinstance(obj, basestring):
+        lst = obj.split(sep)
+        if strip:
+            lst = [v.strip() for v in lst]
+        return lst
+    elif isinstance(obj, (list, tuple)):
+        return obj
+    elif obj is None:
+        return []
+    else:
+        return [obj]
 
 def process_environ(environ, traceback=None, include_params=False):
     # form friendly to json encode
